==> krita_4.4.2+dfsg.orig.tar.xz: krita-4.4.2/libs/ui/kis_filter_manager.h <==
/*
 *  Copyright (c) 2005 Boudewijn Rempt <boud@valdyas.org>
 *  Copyright (c) 2007 Cyrille Berger <cberger@cberger.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef _KIS_FILTER_MANAGER_
#define _KIS_FILTER_MANAGER_

#include <QObject>
#include <kritaui_export.h>
#include <kis_types.h>

class KisViewManager;
class KActionCollection;
class KisActionManager;
class KisView;

/**
 * Create all the filter actions for the specified view and implement re-apply filter
 */
class KRITAUI_EXPORT KisFilterManager : public QObject
{

    Q_OBJECT

public:

    KisFilterManager(KisViewManager * parent);
    ~KisFilterManager() override;
    void setView(QPointer<KisView>imageView);

    void setup(KActionCollection * ac, KisActionManager *actionManager);
    void updateGUI();

    void apply(KisFilterConfigurationSP filterConfig);
    void finish();
    void cancel();
    bool isStrokeRunning() const;

private Q_SLOTS:

    void insertFilter(const QString &name);
    void showFilterDialog(const QString &filterId, KisFilterConfigurationSP overrideDefaultConfig = nullptr);
    void reapplyLastFilter();
    void reapplyLastFilterReprompt();

    void slotStrokeEndRequested();
    void slotStrokeCancelRequested();

private:
    struct Private;
    Private * const d;
};

#endif

==> krita_5.0.2+dfsg.orig.tar.xz: krita-5.0.2/libs/ui/kis_filter_manager.h <==
/*
 *  SPDX-FileCopyrightText: 2005 Boudewijn Rempt <boud@valdyas.org>
 *  SPDX-FileCopyrightText: 2007 Cyrille Berger <cberger@cberger.net>
 *
 *  SPDX-License-Identifier: GPL-2.0-or-later
 */

#ifndef _KIS_FILTER_MANAGER_
#define _KIS_FILTER_MANAGER_

#include <QObject>
#include <kritaui_export.h>
#include <kis_types.h>

class KisViewManager;
class KActionCollection;
class KisActionManager;
class KisView;

/**
 * Create all the filter actions for the specified view and implement re-apply filter
 */
class KRITAUI_EXPORT KisFilterManager : public QObject
{

    Q_OBJECT

public:

    KisFilterManager(KisViewManager * parent);
    ~KisFilterManager() override;
    void setView(QPointer<KisView>imageView);

    void setup(KActionCollection * ac, KisActionManager *actionManager);
    void updateGUI();

    void apply(KisFilterConfigurationSP filterConfig);
    void finish();
    //! Cancel current running stroke
    void cancelRunningStroke();
    //! Call `cancelRunningStroke()` and then delete dialog `d`
    void cancelDialog();
    bool isStrokeRunning() const;

    bool isIdle() const;

    void setFilterAllSelectedFrames(bool filterAllSelectedFrames);
    bool filterAllSelectedFrames();

private Q_SLOTS:

    void insertFilter(const QString &name);
    void showFilterDialog(const QString &filterId, KisFilterConfigurationSP overrideDefaultConfig = nullptr);
    void reapplyLastFilter();
    void reapplyLastFilterReprompt();

    void slotStrokeEndRequested();
    void slotStrokeCancelRequested();

    //! Clean up after filter dialog has been accepted / rejected / closed
    void filterDialogHasFinished(int);

private:
    struct Private;
    QScopedPointer<Private> d;
};

#endif
